@@ -67,7 +67,7 @@ enum {
 #include <tqpixmap.h>
 #include <tqsize.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstandarddirs.h>
 
 TQValueList<tBarcodeInfo> Barkode::s_info;
@@ -283,7 +283,7 @@ const TQString Barkode::parsedValue()
                     v = 'Z';
                 temp[p] = TQChar(v);            
             } else if( sequenceMode() == ALPHANUM ) {
-                qDebug("NOT IMPLEMENTED");
+                tqDebug("NOT IMPLEMENTED");
 /*                char array[36];
                 for( unsigned int i = 'A'; i <= 'Z'; i++ )
                     array[i-'A'] = i;
@@ -683,12 +683,12 @@ void Barkode::initInfo()
 
     PurePostscriptBarcode::init();
 
-    s_haveGnuBarcode = !KStandardDirs::findExe( "barcode" ).isNull();
-    s_havePdfEncode  = !KStandardDirs::findExe( "pdf417_enc" ).isNull();
-    s_haveTBarcode   = false; //!KStandardDirs::findExe( "tbarcodeclient" ).isNull();
+    s_haveGnuBarcode = !TDEStandardDirs::findExe( "barcode" ).isNull();
+    s_havePdfEncode  = !TDEStandardDirs::findExe( "pdf417_enc" ).isNull();
+    s_haveTBarcode   = false; //!TDEStandardDirs::findExe( "tbarcodeclient" ).isNull();
 // TODO: do not yet enable TBarcode2 support
-    s_haveTBarcode2  = !KStandardDirs::findExe( "tbarcode" ).isNull();
-    s_havePurePostscript = !KStandardDirs::findExe( "gs" ).isNull() 
+    s_haveTBarcode2  = !TDEStandardDirs::findExe( "tbarcode" ).isNull();
+    s_havePurePostscript = !TDEStandardDirs::findExe( "gs" ).isNull() 
                              && PurePostscriptBarcode::hasPurePostscriptBarcode();
 
     if( s_haveGnuBarcode )
@@ -917,7 +917,7 @@ void Barkode::initValidators()
 
     if( !xml.open( IO_ReadOnly ) )
     {
-        qDebug( "Cannot read validation rules from %s\n", path.latin1() );
+        tqDebug( "Cannot read validation rules from %s\n", path.latin1() );
         return;
     }
 
